==> vst3sdk-docs-3.7.6_build_18-2-any.pkg.tar.xz: usr/share/doc/vst3sdk-docs/vstinterfaces/search/functions_63.js <==
var searchData=
[
  ['callsuper',['callSuper',['../../vstsdk/structSteinberg_1_1ObjCInstance.html#a40d1c81cfa49dd2dae47e5ee0a678046',1,'Steinberg::ObjCInstance::callSuper(SEL selector, T...args) const '],['../../vstsdk/structSteinberg_1_1ObjCInstance.html#ac9a665bd38b225c0e9d00c3198001b46',1,'Steinberg::ObjCInstance::callSuper(SEL selector, T...args) const ']]],
  ['canprocesssamplesize',['canProcessSampleSize',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioEffect.html#a1c7a40be692f5ed7f009896af248beed',1,'Steinberg::Vst::AudioEffect::canProcessSampleSize()'],['../../vstsdk/classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a1c7a40be692f5ed7f009896af248beed',1,'Steinberg::Vst::SingleComponentEffect::canProcessSampleSize()'],['../classSteinberg_1_1Vst_1_1IAudioProcessor.html#aa1a6f9c030b9b2f5c0602dca309bb23b',1,'Steinberg::Vst::IAudioProcessor::canProcessSampleSize()']]],
  ['canresize',['canResize',['../../base/classSteinberg_1_1IPlugView.html#a07d7a22ae1ef493c4bb22c9411ae7ddf',1,'Steinberg::IPlugView::canResize()'],['../../vstsdk/classSteinberg_1_1CPluginView.html#a0144570339d77dd0b571af3dbb7f73be',1,'Steinberg::CPluginView::canResize()']]],
  ['cardinality',['cardinality',['../../vstsdk/classVST3_1_1Hosting_1_1ClassInfo.html#a44108e1b8189370a1724c960e67b90bf',1,'VST3::Hosting::ClassInfo']]],
  ['category',['category',['../../vstsdk/classVST3_1_1Hosting_1_1ClassInfo.html#a35abfa00d1431e3f0d360064616e23d4',1,'VST3::Hosting::ClassInfo']]],
  ['changesetup',['changeSetup',['../../vstsdk/classSteinberg_1_1Vst_1_1MPE_1_1Processor.html#a02e78035f6fc16da6e780b21af56db66',1,'Steinberg::Vst::MPE::Processor']]],
  ['checkifreallocationneeded',['checkIfReallocationNeeded',['../../vstsdk/classSteinberg_1_1Vst_1_1HostProcessData.html#a67b02cbe272c27f0e21625542d40b33b',1,'Steinberg::Vst::HostProcessData']]],
  ['checksizeconstraint',['checkSizeConstraint',['../../base/classSteinberg_1_1IPlugView.html#adc868253b8260f20a6764e338fecb7e1',1,'Steinberg::IPlugView::checkSizeConstraint()'],['../../vstsdk/classSteinberg_1_1CPluginView.html#ae6caee512822ff27cf93540d4c91479b',1,'Steinberg::CPluginView::checkSizeConstraint()']]],
  ['checkstate',['checkState',['../../vstsdk/classSteinberg_1_1Vst_1_1XmlRepresentationHelper.html#a17146b84f0619e7d5ef2bc0e97dd45c2',1,'Steinberg::Vst::XmlRepresentationHelper']]],
  ['classcount',['classCount',['../../vstsdk/classVST3_1_1Hosting_1_1PluginFactory.html#a32f6bd6953d626694bc1063777056191',1,'VST3::Hosting::PluginFactory']]],
  ['classesdiscardable',['classesDiscardable',['../../vstsdk/classVST3_1_1Hosting_1_1FactoryInfo.html#ac307678d24afa2891c230fc353ab5659',1,'VST3::Hosting::FactoryInfo']]],
  ['classflags',['classFlags',['../../vstsdk/classVST3_1_1Hosting_1_1ClassInfo.html#a5d26d49dc9ccd59d51e7957e8fc52dcb',1,'VST3::Hosting::ClassInfo']]],
  ['classinfo',['ClassInfo',['../../vstsdk/classVST3_1_1Hosting_1_1ClassInfo.html#aa9a778c215c5b807bb8aa42a4e3b7f9f',1,'VST3::Hosting::ClassInfo::ClassInfo() noexcept'],['../../vstsdk/classVST3_1_1Hosting_1_1ClassInfo.html#a8243f55377c20285dbc23fbbde731d1a',1,'VST3::Hosting::ClassInfo::ClassInfo(const PClassInfo &amp;info) noexcept'],['../../vstsdk/classVST3_1_1Hosting_1_1ClassInfo.html#a4dd390f22ad50f579388470dffc6b3a4',1,'VST3::Hosting::ClassInfo::ClassInfo(const PClassInfo2 &amp;info) noexcept'],['../../vstsdk/classVST3_1_1Hosting_1_1ClassInfo.html#a6a81e2fb6e7f9b4f25f770f22c119ce6',1,'VST3::Hosting::ClassInfo::ClassInfo(const PClassInfoW &amp;info) noexcept'],['../../vstsdk/classVST3_1_1Hosting_1_1ClassInfo.html#ad78ae6d6d13bc991896e4d0fa2f94878',1,'VST3::Hosting::ClassInfo::ClassInfo(const ClassInfo &amp;)=default'],['../../vstsdk/classVST3_1_1Hosting_1_1ClassInfo.html#add188ec4f3c25b9948d9414319305fb4',1,'VST3::Hosting::ClassInfo::ClassInfo(ClassInfo &amp;&amp;)=default']]],
  ['classinfos',['classInfos',['../../vstsdk/classVST3_1_1Hosting_1_1PluginFactory.html#a0c9b24609bace7ed28902a36c4c7512f',1,'VST3::Hosting::PluginFactory']]],
  ['clear',['clear',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioBuffer.html#a220bcc74548c37cf5fd56375433ab7d6',1,'Steinberg::Vst::AudioBuffer::clear()'],['../../vstsdk/classSteinberg_1_1Vst_1_1EventList.html#ac8bb3912a3ce86b15842e79d0b421204',1,'Steinberg::Vst::EventList::clear()'],['../../vstsdk/classSteinberg_1_1Vst_1_1ParameterValueQueue.html#ac8bb3912a3ce86b15842e79d0b421204',1,'Steinberg::Vst::ParameterValueQueue::clear()']]],
  ['clear_5fui',['clear_ui',['../../vstsdk/structSteinberg_1_1Vst_1_1RTTransferT.html#aef1e25080421d8398ab840721483c1c9',1,'Steinberg::Vst::RTTransferT']]],
  ['clearall',['clearAll',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioBuffer.html#a798729dca95209ecdc609807a653a2bf',1,'Steinberg::Vst::AudioBuffer']]],
  ['clearqueue',['clearQueue',['../../vstsdk/classSteinberg_1_1Vst_1_1ParameterChanges.html#a7b7f09ace42f57bf958a1a379e935ea9',1,'Steinberg::Vst::ParameterChanges']]],
  ['clone',['clone',['../../base/classSteinberg_1_1ICloneable.html#a01cda1781c6c80ed3aa9091e34be16fb',1,'Steinberg::ICloneable']]],
  ['close',['close',['../../vstsdk/classSteinberg_1_1Vst_1_1VSTGUIEditor.html#af6ee7eacbde6b379b68d954e44f6e549',1,'Steinberg::Vst::VSTGUIEditor']]],
  ['component',['Component',['../../vstsdk/classSteinberg_1_1Vst_1_1Component.html#a0171e1571f18dc6a27c8b041de55feec',1,'Steinberg::Vst::AudioEffect']]],
  ['componentbase',['ComponentBase',['../../vstsdk/classSteinberg_1_1Vst_1_1ComponentBase.html#ab3b1f8979c4bbe983e42010925959fd3',1,'Steinberg::Vst::AudioEffect']]],
  ['componentnondiscardable',['componentNonDiscardable',['../../vstsdk/classVST3_1_1Hosting_1_1FactoryInfo.html#aa5f9ddd2554d3fb83b528c80329aa8bb',1,'VST3::Hosting::FactoryInfo']]],
  ['connect',['connect',['../../vstsdk/classSteinberg_1_1Vst_1_1ComponentBase.html#a170e3042a5e695227c6931fba321debb',1,'Steinberg::Vst::AudioEffect::connect()'],['../../vstsdk/classSteinberg_1_1Vst_1_1ConnectionProxy.html#a8c57e5b4596d750102fbdc6f195ea05f',1,'Steinberg::Vst::ConnectionProxy::connect()'],['../classSteinberg_1_1Vst_1_1IConnectionPoint.html#aa65d68182357737c7a1f7736400565c2',1,'Steinberg::Vst::IConnectionPoint::connect()']]],
  ['connectcomponents',['connectComponents',['../../vstsdk/classSteinberg_1_1Vst_1_1PlugProvider.html#a6049925777740077b65848662a42fd12',1,'Steinberg::Vst::PlugProvider']]],
  ['connectedtohost',['connectedToHost',['../classSteinberg_1_1Vst_1_1IInterAppAudioHost.html#a85482697be15b427dd93a5488beaf9a8',1,'Steinberg::Vst::IInterAppAudioHost']]],
  ['connectionproxy',['ConnectionProxy',['../../vstsdk/classSteinberg_1_1Vst_1_1ConnectionProxy.html#ad51790a646502c1269d5a4ae48441c7d',1,'Steinberg::Vst::ConnectionProxy']]],
  ['conststringtable',['ConstStringTable',['../../base/classSteinberg_1_1ConstStringTable.html#acf88e43da1b31d3d425c80d747bbb1a8',1,'Steinberg::ConstStringTable']]],
  ['contains',['contains',['../../vstsdk/classSteinberg_1_1Vst_1_1PresetFile.html#a0ec5e8e4ff96a6527750a9646d398bb3',1,'Steinberg::Vst::PresetFile']]],
  ['copyto',['copyTo',['../../base/classSteinberg_1_1UString.html#a1372f0527ea276e275d9dfda80572fbe',1,'Steinberg::UString']]],
  ['countattributes',['countAttributes',['../../base/classSteinberg_1_1IAttributes2.html#afab9fceccb1640882d1a4d112b2c5b96',1,'Steinberg::IAttributes2']]],
  ['countclasses',['countClasses',['../../base/classSteinberg_1_1IPluginFactory.html#a64f4f0e4c87d82b5a44d654f4addb960',1,'Steinberg::IPluginFactory']]],
  ['cpluginview',['CPluginView',['../../vstsdk/classSteinberg_1_1CPluginView.html#a7c25891fe7dde6dc274a0ac9f20890a4',1,'Steinberg::CPluginView']]],
  ['create',['create',['../../vstsdk/classVST3_1_1Hosting_1_1Module.html#ab978f80b5342e4a6d9c50939bef14f99',1,'VST3::Hosting::Module']]],
  ['createbuffers',['createBuffers',['../../vstsdk/classSteinberg_1_1Vst_1_1HostProcessData.html#a31f69806459b22b6d413bc10e0bd849c',1,'Steinberg::Vst::HostProcessData']]],
  ['createcontextmenu',['createContextMenu',['../classSteinberg_1_1Vst_1_1IComponentHandler3.html#a0c91e0b43003a34a7f43d0c4b33aa604',1,'Steinberg::Vst::IComponentHandler3']]],
  ['createinstance',['createInstance',['../../base/classSteinberg_1_1IPluginFactory.html#a26a0c88f3703edf621060667eab3eb1f',1,'Steinberg::IPluginFactory::createInstance()'],['../../vstsdk/classSteinberg_1_1Vst_1_1HostApplication.html#aabc455f83c75009b923bc44a3ca49a90',1,'Steinberg::Vst::HostApplication::createInstance()'],['../../vstsdk/classVST3_1_1Hosting_1_1PluginFactory.html#a281e36c942fab4bb6232edd54a57d3f2',1,'VST3::Hosting::PluginFactory::createInstance()'],['../classSteinberg_1_1Vst_1_1IHostApplication.html#a931e5a2ff8867bd8dfdbae1e42b78106',1,'Steinberg::Vst::IHostApplication::createInstance()']]],
  ['createpresetmanager',['createPresetManager',['../classSteinberg_1_1Vst_1_1IInterAppAudioHost.html#ae2524b3ead8126059bc897d1a97047e5',1,'Steinberg::Vst::IInterAppAudioHost']]],
  ['createtests',['createTests',['../classSteinberg_1_1ITestFactory.html#ab9a27b3c53748ad9c1175e862acdc8f4',1,'Steinberg::ITestFactory']]],
  ['createview',['createView',['../../vstsdk/classSteinberg_1_1Vst_1_1EditController.html#a9ed9952fc33a6e0cac96a8f46de5d86c',1,'Steinberg::Vst::EditController::createView()'],['../classSteinberg_1_1Vst_1_1IEditController.html#a1fa4ed10cc0979e5559045104c998b1a',1,'Steinberg::Vst::IEditController::createView()']]]
];

==> vst3sdk-docs-3.7.8_build_34-2-any.pkg.tar.xz: usr/share/doc/vst3sdk-docs/vstinterfaces/search/functions_63.js <==
var searchData=
[
  ['callsuper',['callSuper',['../../vstsdk/structSteinberg_1_1ObjCInstance.html#a40d1c81cfa49dd2dae47e5ee0a678046',1,'Steinberg::ObjCInstance::callSuper(SEL selector, T...args) const '],['../../vstsdk/structSteinberg_1_1ObjCInstance.html#ac9a665bd38b225c0e9d00c3198001b46',1,'Steinberg::ObjCInstance::callSuper(SEL selector, T...args) const ']]],
  ['canprocesssamplesize',['canProcessSampleSize',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioEffect.html#a1c7a40be692f5ed7f009896af248beed',1,'Steinberg::Vst::AudioEffect::canProcessSampleSize()'],['../../vstsdk/classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a1c7a40be692f5ed7f009896af248beed',1,'Steinberg::Vst::SingleComponentEffect::canProcessSampleSize()'],['../classSteinberg_1_1Vst_1_1IAudioProcessor.html#aa1a6f9c030b9b2f5c0602dca309bb23b',1,'Steinberg::Vst::IAudioProcessor::canProcessSampleSize()']]],
  ['canresize',['canResize',['../../base/classSteinberg_1_1IPlugView.html#a07d7a22ae1ef493c4bb22c9411ae7ddf',1,'Steinberg::IPlugView::canResize()'],['../../vstsdk/classSteinberg_1_1CPluginView.html#a0144570339d77dd0b571af3dbb7f73be',1,'Steinberg::CPluginView::canResize()']]],
  ['cardinality',['cardinality',['../../vstsdk/classVST3_1_1Hosting_1_1ClassInfo.html#a44108e1b8189370a1724c960e67b90bf',1,'VST3::Hosting::ClassInfo']]],
  ['category',['category',['../../vstsdk/classVST3_1_1Hosting_1_1ClassInfo.html#a35abfa00d1431e3f0d360064616e23d4',1,'VST3::Hosting::ClassInfo']]],
  ['changesetup',['changeSetup',['../../vstsdk/classSteinberg_1_1Vst_1_1MPE_1_1Processor.html#a02e78035f6fc16da6e780b21af56db66',1,'Steinberg::Vst::MPE::Processor']]],
  ['checkifreallocationneeded',['checkIfReallocationNeeded',['../../vstsdk/classSteinberg_1_1Vst_1_1HostProcessData.html#a67b02cbe272c27f0e21625542d40b33b',1,'Steinberg::Vst::HostProcessData']]],
  ['checksizeconstraint',['checkSizeConstraint',['../../base/classSteinberg_1_1IPlugView.html#adc868253b8260f20a6764e338fecb7e1',1,'Steinberg::IPlugView::checkSizeConstraint()'],['../../vstsdk/classSteinberg_1_1CPluginView.html#ae6caee512822ff27cf93540d4c91479b',1,'Steinberg::CPluginView::checkSizeConstraint()']]],
  ['checkstate',['checkState',['../../vstsdk/classSteinberg_1_1Vst_1_1XmlRepresentationHelper.html#a17146b84f0619e7d5ef2bc0e97dd45c2',1,'Steinberg::Vst::XmlRepresentationHelper']]],
  ['classcount',['classCount',['../../vstsdk/classVST3_1_1Hosting_1_1PluginFactory.html#a32f6bd6953d626694bc1063777056191',1,'VST3::Hosting::PluginFactory']]],
  ['classesdiscardable',['classesDiscardable',['../../vstsdk/classVST3_1_1Hosting_1_1FactoryInfo.html#ac307678d24afa2891c230fc353ab5659',1,'VST3::Hosting::FactoryInfo']]],
  ['classflags',['classFlags',['../../vstsdk/classVST3_1_1Hosting_1_1ClassInfo.html#a5d26d49dc9ccd59d51e7957e8fc52dcb',1,'VST3::Hosting::ClassInfo']]],
  ['classinfo',['ClassInfo',['../../vstsdk/classVST3_1_1Hosting_1_1ClassInfo.html#aa9a778c215c5b807bb8aa42a4e3b7f9f',1,'VST3::Hosting::ClassInfo::ClassInfo() noexcept'],['../../vstsdk/classVST3_1_1Hosting_1_1ClassInfo.html#a8243f55377c20285dbc23fbbde731d1a',1,'VST3::Hosting::ClassInfo::ClassInfo(const PClassInfo &amp;info) noexcept'],['../../vstsdk/classVST3_1_1Hosting_1_1ClassInfo.html#a4dd390f22ad50f579388470dffc6b3a4',1,'VST3::Hosting::ClassInfo::ClassInfo(const PClassInfo2 &amp;info) noexcept'],['../../vstsdk/classVST3_1_1Hosting_1_1ClassInfo.html#a6a81e2fb6e7f9b4f25f770f22c119ce6',1,'VST3::Hosting::ClassInfo::ClassInfo(const PClassInfoW &amp;info) noexcept'],['../../vstsdk/classVST3_1_1Hosting_1_1ClassInfo.html#ad78ae6d6d13bc991896e4d0fa2f94878',1,'VST3::Hosting::ClassInfo::ClassInfo(const ClassInfo &amp;)=default'],['../../vstsdk/classVST3_1_1Hosting_1_1ClassInfo.html#add188ec4f3c25b9948d9414319305fb4',1,'VST3::Hosting::ClassInfo::ClassInfo(ClassInfo &amp;&amp;)=default']]],
  ['classinfos',['classInfos',['../../vstsdk/classVST3_1_1Hosting_1_1PluginFactory.html#a0c9b24609bace7ed28902a36c4c7512f',1,'VST3::Hosting::PluginFactory']]],
  ['clear',['clear',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioBuffer.html#a220bcc74548c37cf5fd56375433ab7d6',1,'Steinberg::Vst::AudioBuffer::clear()'],['../../vstsdk/classSteinberg_1_1Vst_1_1EventList.html#ac8bb3912a3ce86b15842e79d0b421204',1,'Steinberg::Vst::EventList::clear()'],['../../vstsdk/classSteinberg_1_1Vst_1_1ParameterValueQueue.html#ac8bb3912a3ce86b15842e79d0b421204',1,'Steinberg::Vst::ParameterValueQueue::clear()']]],
  ['clear_5fui',['clear_ui',['../../vstsdk/structSteinberg_1_1Vst_1_1RTTransferT.html#aef1e25080421d8398ab840721483c1c9',1,'Steinberg::Vst::RTTransferT']]],
  ['clearall',['clearAll',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioBuffer.html#a798729dca95209ecdc609807a653a2bf',1,'Steinberg::Vst::AudioBuffer']]],
  ['clearqueue',['clearQueue',['../../vstsdk/classSteinberg_1_1Vst_1_1ParameterChanges.html#a7b7f09ace42f57bf958a1a379e935ea9',1,'Steinberg::Vst::ParameterChanges']]],
  ['clone',['clone',['../../base/classSteinberg_1_1ICloneable.html#a01cda1781c6c80ed3aa9091e34be16fb',1,'Steinberg::ICloneable']]],
  ['close',['close',['../../vstsdk/classSteinberg_1_1Vst_1_1VSTGUIEditor.html#af6ee7eacbde6b379b68d954e44f6e549',1,'Steinberg::Vst::VSTGUIEditor']]],
  ['component',['Component',['../../vstsdk/classSteinberg_1_1Vst_1_1Component.html#a0171e1571f18dc6a27c8b041de55feec',1,'Steinberg::Vst::AudioEffect']]],
  ['componentbase',['ComponentBase',['../../vstsdk/classSteinberg_1_1Vst_1_1ComponentBase.html#ab3b1f8979c4bbe983e42010925959fd3',1,'Steinberg::Vst::AudioEffect']]],
  ['componentnondiscardable',['componentNonDiscardable',['../../vstsdk/classVST3_1_1Hosting_1_1FactoryInfo.html#aa5f9ddd2554d3fb83b528c80329aa8bb',1,'VST3::Hosting::FactoryInfo']]],
  ['connect',['connect',['../../vstsdk/classSteinberg_1_1Vst_1_1ComponentBase.html#a170e3042a5e695227c6931fba321debb',1,'Steinberg::Vst::AudioEffect::connect()'],['../../vstsdk/classSteinberg_1_1Vst_1_1ConnectionProxy.html#a8c57e5b4596d750102fbdc6f195ea05f',1,'Steinberg::Vst::ConnectionProxy::connect()'],['../classSteinberg_1_1Vst_1_1IConnectionPoint.html#aa65d68182357737c7a1f7736400565c2',1,'Steinberg::Vst::IConnectionPoint::connect()']]],
  ['connectcomponents',['connectComponents',['../../vstsdk/classSteinberg_1_1Vst_1_1PlugProvider.html#a6049925777740077b65848662a42fd12',1,'Steinberg::Vst::PlugProvider']]],
  ['connectedtohost',['connectedToHost',['../classSteinberg_1_1Vst_1_1IInterAppAudioHost.html#a85482697be15b427dd93a5488beaf9a8',1,'Steinberg::Vst::IInterAppAudioHost']]],
  ['connectionproxy',['ConnectionProxy',['../../vstsdk/classSteinberg_1_1Vst_1_1ConnectionProxy.html#ad51790a646502c1269d5a4ae48441c7d',1,'Steinberg::Vst::ConnectionProxy']]],
  ['conststringtable',['ConstStringTable',['../../base/classSteinberg_1_1ConstStringTable.html#acf88e43da1b31d3d425c80d747bbb1a8',1,'Steinberg::ConstStringTable']]],
  ['contains',['contains',['../../vstsdk/classSteinberg_1_1Vst_1_1PresetFile.html#a0ec5e8e4ff96a6527750a9646d398bb3',1,'Steinberg::Vst::PresetFile']]],
  ['convertspeaker_5fambi_5f1234order_5fto_5fambi567order',['convertSpeaker_Ambi_1234Order_to_Ambi567Order',['../group__speakerArrangements.html#ga3e1ccb637aac3918a31d5b061bcaabe4',1,'Steinberg::Vst::SpeakerArr']]],
  ['convertspeaker_5fambi_5f567order_5fto_5fambi1234order',['convertSpeaker_Ambi_567Order_to_Ambi1234Order',['../group__speakerArrangements.html#gae74e19a6a7653396d1c0e91ff85de6cb',1,'Steinberg::Vst::SpeakerArr']]],
  ['copyto',['copyTo',['../../base/classSteinberg_1_1UString.html#a1372f0527ea276e275d9dfda80572fbe',1,'Steinberg::UString']]],
  ['countattributes',['countAttributes',['../../base/classSteinberg_1_1IAttributes2.html#afab9fceccb1640882d1a4d112b2c5b96',1,'Steinberg::IAttributes2']]],
  ['countclasses',['countClasses',['../../base/classSteinberg_1_1IPluginFactory.html#a64f4f0e4c87d82b5a44d654f4addb960',1,'Steinberg::IPluginFactory']]],
  ['cpluginview',['CPluginView',['../../vstsdk/classSteinberg_1_1CPluginView.html#a7c25891fe7dde6dc274a0ac9f20890a4',1,'Steinberg::CPluginView']]],
  ['create',['create',['../../vstsdk/classVST3_1_1Hosting_1_1Module.html#ab978f80b5342e4a6d9c50939bef14f99',1,'VST3::Hosting::Module']]],
  ['createbuffers',['createBuffers',['../../vstsdk/classSteinberg_1_1Vst_1_1HostProcessData.html#a31f69806459b22b6d413bc10e0bd849c',1,'Steinberg::Vst::HostProcessData']]],
  ['createcontextmenu',['createContextMenu',['../classSteinberg_1_1Vst_1_1IComponentHandler3.html#a0c91e0b43003a34a7f43d0c4b33aa604',1,'Steinberg::Vst::IComponentHandler3']]],
  ['createinstance',['createInstance',['../../base/classSteinberg_1_1IPluginFactory.html#a26a0c88f3703edf621060667eab3eb1f',1,'Steinberg::IPluginFactory::createInstance()'],['../../vstsdk/classSteinberg_1_1Vst_1_1HostApplication.html#aabc455f83c75009b923bc44a3ca49a90',1,'Steinberg::Vst::HostApplication::createInstance()'],['../../vstsdk/classVST3_1_1Hosting_1_1PluginFactory.html#a281e36c942fab4bb6232edd54a57d3f2',1,'VST3::Hosting::PluginFactory::createInstance()'],['../classSteinberg_1_1Vst_1_1IHostApplication.html#a931e5a2ff8867bd8dfdbae1e42b78106',1,'Steinberg::Vst::IHostApplication::createInstance()']]],
  ['createpresetmanager',['createPresetManager',['../classSteinberg_1_1Vst_1_1IInterAppAudioHost.html#ae2524b3ead8126059bc897d1a97047e5',1,'Steinberg::Vst::IInterAppAudioHost']]],
  ['createtests',['createTests',['../classSteinberg_1_1ITestFactory.html#ab9a27b3c53748ad9c1175e862acdc8f4',1,'Steinberg::ITestFactory']]],
  ['createview',['createView',['../../vstsdk/classSteinberg_1_1Vst_1_1EditController.html#a9ed9952fc33a6e0cac96a8f46de5d86c',1,'Steinberg::Vst::EditController::createView()'],['../classSteinberg_1_1Vst_1_1IEditController.html#a1fa4ed10cc0979e5559045104c998b1a',1,'Steinberg::Vst::IEditController::createView()']]]
];
